@@ -100,32 +100,49 @@ var menudata={children:[
 {text:"u",url:"namespacemembers_type_u.html#index_u"},
 {text:"v",url:"namespacemembers_type_v.html#index_v"},
 {text:"w",url:"namespacemembers_type_w.html#index_w"}]},
-{text:"Enumerations",url:"namespacemembers_enum.html"},
+{text:"Enumerations",url:"namespacemembers_enum.html",children:[
+{text:"a",url:"namespacemembers_enum.html#index_a"},
+{text:"b",url:"namespacemembers_enum.html#index_b"},
+{text:"c",url:"namespacemembers_enum.html#index_c"},
+{text:"d",url:"namespacemembers_enum.html#index_d"},
+{text:"f",url:"namespacemembers_enum.html#index_f"},
+{text:"g",url:"namespacemembers_enum.html#index_g"},
+{text:"i",url:"namespacemembers_enum.html#index_i"},
+{text:"k",url:"namespacemembers_enum.html#index_k"},
+{text:"l",url:"namespacemembers_enum.html#index_l"},
+{text:"m",url:"namespacemembers_enum.html#index_m"},
+{text:"n",url:"namespacemembers_enum.html#index_n"},
+{text:"o",url:"namespacemembers_enum.html#index_o"},
+{text:"p",url:"namespacemembers_enum.html#index_p"},
+{text:"r",url:"namespacemembers_enum.html#index_r"},
+{text:"s",url:"namespacemembers_enum.html#index_s"},
+{text:"t",url:"namespacemembers_enum.html#index_t"},
+{text:"v",url:"namespacemembers_enum.html#index_v"}]},
 {text:"Enumerator",url:"namespacemembers_eval.html",children:[
 {text:"a",url:"namespacemembers_eval.html#index_a"},
-{text:"b",url:"namespacemembers_eval_b.html#index_b"},
-{text:"c",url:"namespacemembers_eval_c.html#index_c"},
-{text:"d",url:"namespacemembers_eval_d.html#index_d"},
-{text:"e",url:"namespacemembers_eval_e.html#index_e"},
-{text:"f",url:"namespacemembers_eval_f.html#index_f"},
-{text:"g",url:"namespacemembers_eval_g.html#index_g"},
-{text:"h",url:"namespacemembers_eval_h.html#index_h"},
-{text:"i",url:"namespacemembers_eval_i.html#index_i"},
-{text:"l",url:"namespacemembers_eval_l.html#index_l"},
-{text:"m",url:"namespacemembers_eval_m.html#index_m"},
-{text:"n",url:"namespacemembers_eval_n.html#index_n"},
-{text:"o",url:"namespacemembers_eval_o.html#index_o"},
-{text:"p",url:"namespacemembers_eval_p.html#index_p"},
-{text:"q",url:"namespacemembers_eval_q.html#index_q"},
-{text:"r",url:"namespacemembers_eval_r.html#index_r"},
-{text:"s",url:"namespacemembers_eval_s.html#index_s"},
-{text:"t",url:"namespacemembers_eval_t.html#index_t"},
-{text:"u",url:"namespacemembers_eval_u.html#index_u"},
-{text:"v",url:"namespacemembers_eval_v.html#index_v"},
-{text:"w",url:"namespacemembers_eval_w.html#index_w"},
-{text:"x",url:"namespacemembers_eval_x.html#index_x"},
-{text:"y",url:"namespacemembers_eval_y.html#index_y"},
-{text:"z",url:"namespacemembers_eval_z.html#index_z"}]}]}]},
+{text:"b",url:"namespacemembers_eval.html#index_b"},
+{text:"c",url:"namespacemembers_eval.html#index_c"},
+{text:"d",url:"namespacemembers_eval.html#index_d"},
+{text:"e",url:"namespacemembers_eval.html#index_e"},
+{text:"f",url:"namespacemembers_eval.html#index_f"},
+{text:"g",url:"namespacemembers_eval.html#index_g"},
+{text:"h",url:"namespacemembers_eval.html#index_h"},
+{text:"i",url:"namespacemembers_eval.html#index_i"},
+{text:"l",url:"namespacemembers_eval.html#index_l"},
+{text:"m",url:"namespacemembers_eval.html#index_m"},
+{text:"n",url:"namespacemembers_eval.html#index_n"},
+{text:"o",url:"namespacemembers_eval.html#index_o"},
+{text:"p",url:"namespacemembers_eval.html#index_p"},
+{text:"q",url:"namespacemembers_eval.html#index_q"},
+{text:"r",url:"namespacemembers_eval.html#index_r"},
+{text:"s",url:"namespacemembers_eval.html#index_s"},
+{text:"t",url:"namespacemembers_eval.html#index_t"},
+{text:"u",url:"namespacemembers_eval.html#index_u"},
+{text:"v",url:"namespacemembers_eval.html#index_v"},
+{text:"w",url:"namespacemembers_eval.html#index_w"},
+{text:"x",url:"namespacemembers_eval.html#index_x"},
+{text:"y",url:"namespacemembers_eval.html#index_y"},
+{text:"z",url:"namespacemembers_eval.html#index_z"}]}]}]},
 {text:"Classes",url:"annotated.html",children:[
 {text:"Class List",url:"annotated.html"},
 {text:"Class Hierarchy",url:"hierarchy.html"},
@@ -189,7 +206,8 @@ var menudata={children:[
 {text:"z",url:"functions_func_z.html#index_z"},
 {text:"~",url:"functions_func_~.html#index__7E"}]},
 {text:"Variables",url:"functions_vars.html",children:[
-{text:"a",url:"functions_vars.html#index_a"},
+{text:"_",url:"functions_vars.html#index__5F"},
+{text:"a",url:"functions_vars_a.html#index_a"},
 {text:"b",url:"functions_vars_b.html#index_b"},
 {text:"c",url:"functions_vars_c.html#index_c"},
 {text:"d",url:"functions_vars_d.html#index_d"},
@@ -198,6 +216,7 @@ var menudata={children:[
 {text:"g",url:"functions_vars_g.html#index_g"},
 {text:"h",url:"functions_vars_h.html#index_h"},
 {text:"i",url:"functions_vars_i.html#index_i"},
+{text:"k",url:"functions_vars_k.html#index_k"},
 {text:"l",url:"functions_vars_l.html#index_l"},
 {text:"m",url:"functions_vars_m.html#index_m"},
 {text:"n",url:"functions_vars_n.html#index_n"},
@@ -210,8 +229,7 @@ var menudata={children:[
 {text:"v",url:"functions_vars_v.html#index_v"},
 {text:"w",url:"functions_vars_w.html#index_w"},
 {text:"x",url:"functions_vars_x.html#index_x"},
-{text:"y",url:"functions_vars_y.html#index_y"},
-{text:"z",url:"functions_vars_z.html#index_z"}]},
+{text:"y",url:"functions_vars_y.html#index_y"}]},
 {text:"Typedefs",url:"functions_type.html",children:[
 {text:"_",url:"functions_type.html#index__5F"},
 {text:"a",url:"functions_type_a.html#index_a"},
@@ -223,6 +241,7 @@ var menudata={children:[
 {text:"g",url:"functions_type_g.html#index_g"},
 {text:"h",url:"functions_type_h.html#index_h"},
 {text:"i",url:"functions_type_i.html#index_i"},
+{text:"k",url:"functions_type_k.html#index_k"},
 {text:"l",url:"functions_type_l.html#index_l"},
 {text:"m",url:"functions_type_m.html#index_m"},
 {text:"n",url:"functions_type_n.html#index_n"},
@@ -256,16 +275,12 @@ var menudata={children:[
 {text:"t",url:"functions_eval.html#index_t"},
 {text:"u",url:"functions_eval.html#index_u"},
 {text:"v",url:"functions_eval.html#index_v"},
-{text:"w",url:"functions_eval.html#index_w"},
-{text:"x",url:"functions_eval.html#index_x"},
-{text:"y",url:"functions_eval.html#index_y"},
-{text:"z",url:"functions_eval.html#index_z"}]},
-{text:"Related Functions",url:"functions_rela.html",children:[
+{text:"w",url:"functions_eval.html#index_w"}]},
+{text:"Related Symbols",url:"functions_rela.html",children:[
 {text:":",url:"functions_rela.html#index_:"},
 {text:"a",url:"functions_rela.html#index_a"},
 {text:"b",url:"functions_rela.html#index_b"},
 {text:"c",url:"functions_rela.html#index_c"},
-{text:"f",url:"functions_rela.html#index_f"},
 {text:"i",url:"functions_rela.html#index_i"},
 {text:"l",url:"functions_rela.html#index_l"},
 {text:"m",url:"functions_rela.html#index_m"},
@@ -279,27 +294,39 @@ var menudata={children:[
 {text:"File List",url:"files.html"},
 {text:"File Members",url:"globals.html",children:[
 {text:"All",url:"globals.html",children:[
-{text:"a",url:"globals.html#index_a"},
-{text:"b",url:"globals.html#index_b"},
-{text:"c",url:"globals.html#index_c"},
-{text:"d",url:"globals.html#index_d"},
-{text:"e",url:"globals.html#index_e"},
-{text:"f",url:"globals.html#index_f"},
-{text:"g",url:"globals.html#index_g"},
-{text:"i",url:"globals.html#index_i"},
-{text:"l",url:"globals.html#index_l"},
-{text:"m",url:"globals.html#index_m"},
-{text:"n",url:"globals.html#index_n"},
-{text:"o",url:"globals.html#index_o"},
-{text:"p",url:"globals.html#index_p"},
-{text:"q",url:"globals.html#index_q"},
-{text:"r",url:"globals.html#index_r"},
-{text:"s",url:"globals.html#index_s"},
-{text:"t",url:"globals.html#index_t"},
-{text:"u",url:"globals.html#index_u"},
-{text:"v",url:"globals.html#index_v"},
-{text:"w",url:"globals.html#index_w"}]},
-{text:"Functions",url:"globals_func.html"},
+{text:"_",url:"globals.html#index__5F"},
+{text:"a",url:"globals_a.html#index_a"},
+{text:"b",url:"globals_b.html#index_b"},
+{text:"c",url:"globals_c.html#index_c"},
+{text:"d",url:"globals_d.html#index_d"},
+{text:"e",url:"globals_e.html#index_e"},
+{text:"f",url:"globals_f.html#index_f"},
+{text:"g",url:"globals_g.html#index_g"},
+{text:"h",url:"globals_h.html#index_h"},
+{text:"i",url:"globals_i.html#index_i"},
+{text:"k",url:"globals_k.html#index_k"},
+{text:"l",url:"globals_l.html#index_l"},
+{text:"m",url:"globals_m.html#index_m"},
+{text:"n",url:"globals_n.html#index_n"},
+{text:"o",url:"globals_o.html#index_o"},
+{text:"p",url:"globals_p.html#index_p"},
+{text:"q",url:"globals_q.html#index_q"},
+{text:"r",url:"globals_r.html#index_r"},
+{text:"s",url:"globals_s.html#index_s"},
+{text:"t",url:"globals_t.html#index_t"},
+{text:"u",url:"globals_u.html#index_u"},
+{text:"v",url:"globals_v.html#index_v"},
+{text:"w",url:"globals_w.html#index_w"}]},
+{text:"Functions",url:"globals_func.html",children:[
+{text:"a",url:"globals_func.html#index_a"},
+{text:"c",url:"globals_func_c.html#index_c"},
+{text:"g",url:"globals_func_g.html#index_g"},
+{text:"h",url:"globals_func_h.html#index_h"},
+{text:"m",url:"globals_func_m.html#index_m"},
+{text:"p",url:"globals_func_p.html#index_p"},
+{text:"r",url:"globals_func_r.html#index_r"},
+{text:"s",url:"globals_func_s.html#index_s"},
+{text:"v",url:"globals_func_v.html#index_v"}]},
 {text:"Variables",url:"globals_vars.html"},
 {text:"Typedefs",url:"globals_type.html"},
 {text:"Enumerations",url:"globals_enum.html"},
@@ -324,13 +351,19 @@ var menudata={children:[
 {text:"v",url:"globals_eval.html#index_v"},
 {text:"w",url:"globals_eval.html#index_w"}]},
 {text:"Macros",url:"globals_defs.html",children:[
-{text:"a",url:"globals_defs.html#index_a"},
-{text:"b",url:"globals_defs.html#index_b"},
-{text:"c",url:"globals_defs.html#index_c"},
-{text:"e",url:"globals_defs.html#index_e"},
-{text:"i",url:"globals_defs.html#index_i"},
-{text:"o",url:"globals_defs.html#index_o"},
-{text:"p",url:"globals_defs.html#index_p"},
-{text:"t",url:"globals_defs.html#index_t"},
-{text:"u",url:"globals_defs.html#index_u"},
-{text:"v",url:"globals_defs.html#index_v"}]}]}]}]}
+{text:"_",url:"globals_defs.html#index__5F"},
+{text:"a",url:"globals_defs_a.html#index_a"},
+{text:"b",url:"globals_defs_b.html#index_b"},
+{text:"c",url:"globals_defs_c.html#index_c"},
+{text:"d",url:"globals_defs_d.html#index_d"},
+{text:"e",url:"globals_defs_e.html#index_e"},
+{text:"i",url:"globals_defs_i.html#index_i"},
+{text:"k",url:"globals_defs_k.html#index_k"},
+{text:"l",url:"globals_defs_l.html#index_l"},
+{text:"n",url:"globals_defs_n.html#index_n"},
+{text:"o",url:"globals_defs_o.html#index_o"},
+{text:"p",url:"globals_defs_p.html#index_p"},
+{text:"r",url:"globals_defs_r.html#index_r"},
+{text:"t",url:"globals_defs_t.html#index_t"},
+{text:"u",url:"globals_defs_u.html#index_u"},
+{text:"v",url:"globals_defs_v.html#index_v"}]}]}]}]}
