@@ -2,7 +2,7 @@ var indexSectionsWithContent =
 {
   0: ":_abcdefghijklmnopqrstuvwxyz~",
   1: "abcdefghijklmnopqrstuvw",
-  2: "cdghlnopsu",
+  2: "cdghlnosu",
   3: "abcdefghilmnopqrstuv",
   4: "abcdefghijklmnopqrstuvwxyz~",
   5: "_abcdefghiklmnoprstuvwxy",
@@ -11,7 +11,7 @@ var indexSectionsWithContent =
   8: "abcdefghiklmnopqrstuvwxyz",
   9: ":abcilmoprstv",
   10: "_abcdeiklnoprtuv",
-  11: "abcdfhnorstu"
+  11: "abcdefhilmnopqrstuw"
 };
 
 var indexSectionNames =
